tile_matmul

Function tile_matmul 

pub fn tile_matmul(shape: &MatMulShape, defaults: &TilingDefaults) -> TilingPlan
Compute a tiling plan for a MatMul operation.

Tile sizes are clamped to the actual dimension size when the dimension is smaller than the default tile size.